@@ -273,12 +273,17 @@ void detaileddialog::setPowerConsumption() {
 
 	// refresh battery collection
 	primaryBatteries = hwinfo->getPrimaryBatteries();
-	int rate = primaryBatteries->getCurrentRate();
+	double rate = primaryBatteries->getCurrentRate();
 
-	if (rate > 0 && !primaryBatteries->getChargeLevelUnit().isEmpty()) {	
+	if (rate > 0 && !primaryBatteries->getChargeLevelUnit().isEmpty()) {
 
 		TQString _val;
-		_val.setNum(rate);
+		if (rate > 100) {
+			_val = TQString("%L1").arg((int)rate);
+		}
+		else {
+			_val = TQString("%L1").arg(rate, 0, 'g', 3);
+		}
 		_val += " " + primaryBatteries->getChargeLevelUnit().remove('h');
 
 		tl_powerConsValue->setText(_val);
